@@ -12,6 +12,7 @@
 """
 from __future__ import absolute_import
 
+from collections import MutableSequence
 from copy import deepcopy
 from functools import partial as _partial, reduce
 from operator import itemgetter
@@ -242,6 +243,8 @@ class Signature(dict):
 
     def append_to_list_option(self, key, value):
         items = self.options.setdefault(key, [])
+        if not isinstance(items, MutableSequence):
+            items = self.options[key] = [items]
         if value not in items:
             items.append(value)
         return value
@@ -639,7 +642,7 @@ class chord(Signature):
 
 
 def signature(varies, *args, **kwargs):
-    if not (args or kwargs) and isinstance(varies, dict):
+    if isinstance(varies, dict):
         if isinstance(varies, Signature):
             return varies.clone()
         return Signature.from_dict(varies)
